Skip to content
Jenkins
wrf_clubb_silhs_parallel_ifort
#144
Search
Sign in
Status
Changes
Console Output
Git Build Data
Pipeline Overview
Pipeline Steps
Previous Build
Next Build
Changes
Started by Vince Larson
Started 4 yr 9 mo ago
Took 18 min on built-in
Changing the run duration of the WRF-CLUBB parallelization test from 60 minutes to 10 minutes.
(
1fa8a22
)
WRF/test/em_quarter_ss/namelist.input.parallel_test
noreply
at
5:32 PM 1/6/22